@@ -1,11 +1,11 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2019-2020 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2019 -- leonerd@leonerd.org.uk
 
 package Alien::libtickit;
 
-our $VERSION = '0.08_003';
+our $VERSION = '0.01';
 
 use POSIX qw( WEXITSTATUS );
 
@@ -35,7 +35,7 @@ provides a simple access to its configuration. If not, the process of
 installing it will install a locally-bundled copy of the library into perl's
 arch-specific library directory.
 
-This module bundles F<libtickit> version 0.4.0-RC4.
+This module bundles F<libtickit> version 0.2.
 
 =head1 METHODS
 
@@ -75,6 +75,7 @@ sub _get_pkgconfig
    unshift @args, "--$method";
 
    local $ENV{PKG_CONFIG_PATH} = "$libdir/pkgconfig/" if $use_bundled;
+   unshift @args, "--define-variable=libdir=$libdir" if $use_bundled;
 
    open my $eupc, "-|", "pkg-config", @args, $module or
       die "Cannot popen pkg-config - $!";
@@ -86,6 +87,12 @@ sub _get_pkgconfig
    return $ret;
 }
 
+sub libs
+{
+   # Append RPATH so that runtime linking actually works
+   return _get_pkgconfig( libs => @_ ) . ( $use_bundled ? " -Wl,-R$libdir" : "" );
+}
+
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
